==> dde-network-core_1.0.57.orig.tar.xz: dde-network-core-1.0.57/dss-network-plugin/translations/dss-network-plugin_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1条新消息</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>正在连接%1</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1已连接</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%1已断开</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>未能加入%1，请检查路由器或网线。</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>未能加入%1，请尝试靠近无线路由器</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>连接失败，未能加入%1，密码不正确</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>连接%1需要密码</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>%1 802.11 WLAN网络无法找到</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>有线连接</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>热点</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>协议</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>安全类型</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>频段</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>网络通道</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>接口</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>子网掩码</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>网关</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>首选DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>前缀</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>速率</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>设备已禁用</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>已连接网络但无法访问互联网</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未连接</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>未插入网线</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>正在连接</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>认证中</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>正在获取IP地址</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>已连接</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>已断开</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP地址冲突</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>失败</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>获取地址中</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>有线网络</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>有线网络%1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>无线网络</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>无线网络%1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>设备已禁用</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>未插入网线</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未连接</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>正在连接</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>已连接网络但无法访问互联网</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>连接失败</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP地址冲突</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>关闭有线网络</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>启用有线网络</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>关闭无线网络</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>启用无线网络</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>关闭网络</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>启用网络</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>网络设置</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.4.orig.tar.xz: dde-network-core-1.1.4/dss-network-plugin/translations/dss-network-plugin_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1条新消息</translation>
    </message>
</context>
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>无线网络</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>有线网络</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>正在连接%1</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1已连接</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%1已断开</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>未能加入%1，请检查路由器或网线。</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>未能加入%1，请尝试靠近无线路由器</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>连接失败，未能加入%1，密码不正确</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>连接%1需要密码</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>%1 802.11 WLAN网络无法找到</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>连接到隐藏网络</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>请输入密码</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>连 接</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>请输入网络名称（SSID）</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>热点</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>协议</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>安全类型</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>网络通道</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>频段</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>接口</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>子网掩码</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>网关</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>首选DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>前缀</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>速率</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>设备已禁用</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>已连接网络但无法访问互联网</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未连接</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>未插入网线</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>正在连接</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>认证中</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>正在获取IP地址</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>已连接</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>已断开</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP地址冲突</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>失败</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>获取地址中</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>有线网络</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>有线网络%1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>无线网络</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>无线网络%1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>设备已禁用</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>未插入网线</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未连接</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>正在连接</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>已连接网络但无法访问互联网</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>连接失败</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP地址冲突</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>关闭有线网络</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>启用有线网络</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>关闭无线网络</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>启用无线网络</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>关闭网络</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>启用网络</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>网络设置</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>有线连接</translation>
    </message>
</context>
</TS>
